<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :isShowHide="true"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="returnStockTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 修改 -->
      <returnStockForm
        :currshowlist.sync="showReturnStockForm"
        :returnStockId="currReturnStockId"
        :return-stock-obj="currReturnStockObj"
        @refreshDataList="getData"
      />
    </basic-container>
  </div>
</template>

<script>
import { fetchList, addObj, delObj } from '@/api/warehouse/returnstock'
import returnStockForm from './returnstock-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
export default {
  data() {
    return {
      ajaxFun: fetchList,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'returnstock',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: true, // 高级查询按钮
        defaultOrderBy: { column: 'createTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 退料单号
          {
            minWidth: '140',
            prop: 'applySerialNo',
            label: '退料单号',
            sort: true,
            isTrue: true,
            formatter: (row, column, cellValue) => {
              return cellValue
            },
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 申请人
          {
            minWidth: '120',
            prop: 'createUserName',
            label: '申请人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 状态
          {
            minWidth: '200',
            prop: 'state',
            label: '状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getStatusOptionList()
            },
            formatter: (row, column, cellValue) => {
              let formatVal = ''
              if (cellValue === 'draft') {
                formatVal = '草稿'
              } else if (cellValue === 'processing') {
                formatVal = '进行中'
              } else {
                formatVal = '已执行'
              }
              return formatVal
            }
          },
          // 申请时间
          {
            minWidth: '200',
            width: '300',
            prop: 'createTime',
            label: '申请时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle,
            show: {
              val: ['draft'],
              key: 'state'
            }
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      statusOptionList: [
        {
          value: 'draft',
          label: '草稿'
        },
        {
          value: 'processing',
          label: '进行中'
        },
        {
          value: 'processed',
          label: '已执行'
        }
      ],
      mulReturnStock: [],
      currReturnStockId: null,
      currReturnStockObj: null,
      showReturnStockForm: false
    }
  },
  components: {
    ttable,
    returnStockForm
  },
  created() {},
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 选中仓库行
    handleSelectionChange(val) {
      this.mulReturnStock = val
    },
    // 获取数据列表
    getData() {
      this.$refs.returnStockTable.getDataList()
    },
    getStatusOptionList() {
      return this.statusOptionList
    },
    // 新增
    addHandle() {
      addObj(null).then((response) => {
        this.getData()
      })
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.showReturnStockForm = true
      // this.returnStockId = row.id
      this.currReturnStockId = row.id
      this.currReturnStockObj = row
    },
    // 删除
    deleteHandle(row) {
      const ids = [row.id]
      const param = {
        idList: ids
      }
      delObj(ids).then((response) => {
        console.log(response)
        this.getData()
      })
    }
  }
}
</script>
